@@ -7,11 +7,13 @@ __author__ = 'yarnaid'
 import tools.convertion as convert
 import pixelmap as pixelmap
 import properties as properties
+import os
 
 
 class Alm(properties.Multipoled):
 
     name = None
+    temp = True
 
     def get_attrs(self, **kwargs):
         res = {'lmax': self.lmax,
@@ -22,14 +24,22 @@ class Alm(properties.Multipoled):
     def __init__(self, **kwargs):
         for k, v in kwargs.items():
             setattr(self, k, v)
+        if os.path.exists(self.name) and self.name.count('tmp') < 1:
+            self.temp = False
 
     def __setattr__(self, name, value):
+        if name == 'name' and os.path.exists(value) and value.count('tmp') < 1:
+            self.__dict__['temp'] = False
         try:
             return super(Alm, self).__setattr__(name, value)
         except:
             self.__dict__[name] = value
         return value
 
+    def __del__(self):
+        if self.temp:
+            os.remove(self.name)
+
     def to_map(self, map_name=None, **kwargs):
         attrs = self.get_attrs(**kwargs)
         attrs['name'] = convert.alm_to_map(
@@ -71,3 +81,8 @@ class Alm(properties.Multipoled):
 
     def to_cl(self, **kwargs):
         return convert.alm_to_cl(self.name, **self.get_attrs(**kwargs))
+
+    def update_ls(self, update_name=None, **kwargs):
+        self.name = convert.alm_update_ls(
+            self.name, update_name, **self.get_attrs(**kwargs))
+        return self.name
