@@ -22,8 +22,8 @@ class PointSource(object):
         for k, v in kwargs.items():
             setattr(self, k, v)
 
-    def to_pixelmap(self, map_name=None, **kwargs):
-        map_name = conv.points_to_map(self.name, **kwargs)
+    def to_pixelmap(self, map_name=None, tp='fp', **kwargs):
+        map_name = conv.asci_to_map(self.name, tp, map_name=map_name, **kwargs)
         attrs = kwargs.copy()
         attrs['name'] = map_name
         pixmap = pixelmap.gPixelMap(**attrs)
