@@ -159,12 +159,12 @@ def remove_nx_np(bad_args):
     return args
 
 
-def alm_to_cl(alm_name, **kwargs):
+def alm_to_spec(alm_name, cl=True, **kwargs):
     if len(set(['lmax', 'l', 'lmin']).intersection(kwargs)) < 1:
         raise ValueError(
             '[%s]: lmax or l or lmin must be given' % (alm_to_cl.__name__))
     opt_args = kwargs_props_to_glesp_args(**kwargs)
-    args = [tools.binaries['alm2dl'], '-cl', alm_name]
+    args = [tools.binaries['alm2dl'], '-cl' if cl else '', alm_name]
     args.extend(opt_args)
     args = remove_nx_np(args)
     with open(os.devnull) as stderr:
@@ -174,6 +174,14 @@ def alm_to_cl(alm_name, **kwargs):
     return cl_data
 
 
+def alm_to_cl(alm_name, **kwargs):
+    return alm_to_spec(alm_name=alm_name, cl=True, **kwargs)
+
+
+def alm_to_dl(alm_name, **kwargs):
+    return alm_to_spec(alm_name=alm_name, cl=False, **kwargs)
+
+
 def mask_map(map_name, mask_name, masked_map_name=None, **kwargs):
     check_file(map_name)
     check_file(mask_name)
@@ -199,7 +207,7 @@ def asci_to_map(asci_name, tp, map_name=None, **kwargs):
         )
     map_name = tools.get_out_name(map_name, suffix='map_from_points.fit')
     opt_args = kwargs_props_to_glesp_args(**kwargs)
-    args = [tools.binaries['mappat'], '-'+tp, asci_name, '-o', map_name]
+    args = [tools.binaries['mappat'], '-' + tp, asci_name, '-o', map_name]
     args.extend(opt_args)
     tools.run_cmd(args, debug_msg='point to map')
     return check_file(map_name)
@@ -335,7 +343,7 @@ def reflect_map(map_name, rtype, reflected_name=None, **kwargs):
     check_file(map_name)
     args = [tools.binaries['difmap'], map_name, '-o', reflected_name,
             '-mir{}'.format(rtype.upper()),
-            ]
+    ]
     opt_args = kwargs_to_glesp_args(**kwargs)
     args.extend(opt_args)
     args = remove_nx_np(args)
@@ -366,3 +374,53 @@ def alm_update_ls(alm_name, update_alm_name=None, **kwargs):
     args = remove_nx_np(args)
     tools.run_cmd(args, debug_msg='update alm l')
     return check_file(update_alm_name)
+
+
+def cl_to_smth(cl_name, out_key='o', lmax=None, nx=None, lmin=0, smth_name=None, **kwargs):
+    if out_key not in ('o', 'ao'):
+        raise ValueError('out_key must be in ("o", "ao") for pixelmap and alm, {} got'.format(out_key))
+    check_file(cl_name)
+    smth_name = tools.get_out_name(smth_name, suffix='rand_alm_from_cl')
+    if not lmax:
+        try:
+            cl_data = np.loadtxt(cl_name, dtype=('f8', 'f8'))
+        except:
+            raise IOError('Cannot read cl file {}'.format(cl_name))
+        lmax = int(cl_data.T[0].max())
+        lmin = int(cl_data.T[0].min())
+    if not nx:
+        nx = lmax * 2 + 1
+    opt_args = kwargs_to_glesp_args(**kwargs)
+    args = [tools.binaries['cl2map'], '-Cl', cl_name,
+            '-lmax', lmax, '-lmin', lmin, '-nx', nx, '-np', nx * 2,
+            '-' + out_key, smth_name]
+    if 'a' in out_key:
+        args.append('-nomap')
+    args.extend(opt_args)
+    tools.run_cmd(args, debug_msg='cl to map')
+    return {'name': check_file(smth_name),
+            'lmax': lmax,
+            'nx': nx,
+            'lmin': lmin,
+            'kwargs': kwargs,
+    }
+
+
+def cl_to_alm(cl_name, lmax=None, nx=None, lmin=0, alm_name=None, **kwargs):
+    return cl_to_smth(cl_name,
+                      out_key='ao',
+                      lmax=lmax,
+                      nx=nx,
+                      lmin=lmin,
+                      smth_name=alm_name,
+                      **kwargs)
+
+
+def cl_to_map(cl_name, lmax=None, nx=None, lmin=0, map_name=None, **kwargs):
+    return cl_to_smth(cl_name,
+                      out_key='o',
+                      lmax=lmax,
+                      nx=nx,
+                      lmin=lmin,
+                      smth_name=map_name,
+                      **kwargs)
